emacs-orgmode@gnu.org archives
 help / color / mirror / code / Atom feed
From: Jonas Bernoulli <jonas@bernoul.li>
To: emacs-orgmode <emacs-orgmode@gnu.org>
Subject: [PATCH] Fix typos
Date: Tue, 12 Nov 2019 14:44:05 +0100	[thread overview]
Message-ID: <874kz9mcpm.fsf@bernoul.li> (raw)

Please consider applying the below patch, which fixes many spelling
errors.  I did not write a commit message that lists every file and
function/variable that happened to contain a typo.  That seems rather
unnecessary for this type of change, but if you want that I can do it.

In addition to the below typos I also found some things I don't know
how to deal with:
* "visibile" as a supported value of org-s5-control-visibility
* "ded" appearing in doc/orgcard.tex

Cheers,
Jonas

---
 README_maintainer                 |  4 ++--
 contrib/lisp/ob-oz.el             |  2 +-
 contrib/lisp/ob-spice.el          |  6 +++---
 contrib/lisp/ol-notmuch.el        |  6 +++---
 contrib/lisp/org-annotate-file.el |  2 +-
 contrib/lisp/org-collector.el     |  2 +-
 contrib/lisp/org-expiry.el        |  2 +-
 contrib/lisp/org-mac-link.el      |  2 +-
 contrib/lisp/org-passwords.el     |  2 +-
 contrib/lisp/org-screenshot.el    |  6 +++---
 contrib/lisp/org-sudoku.el        |  2 +-
 contrib/lisp/org-toc.el           |  2 +-
 contrib/lisp/orgtbl-sqlinsert.el  |  2 +-
 contrib/lisp/ox-deck.el           | 16 ++++++++--------
 contrib/lisp/ox-groff.el          |  2 +-
 contrib/lisp/ox-koma-letter.el    |  2 +-
 contrib/lisp/ox-s5.el             |  4 ++--
 contrib/scripts/StartOzServer.oz  |  4 ++--
 doc/.aspell.org.conf              |  2 +-
 doc/doc-setup.org                 |  2 +-
 doc/org-guide.org                 |  2 +-
 doc/org-manual.org                | 10 +++++-----
 etc/ORG-NEWS                      | 26 +++++++++++++-------------
 lisp/ob-C.el                      |  6 +++---
 lisp/org-agenda.el                |  8 ++++----
 lisp/org-attach-git.el            |  4 ++--
 lisp/org-feed.el                  |  2 +-
 lisp/org-plot.el                  |  2 +-
 lisp/org-table.el                 |  2 +-
 lisp/org.el                       |  6 +++---
 lisp/ox-odt.el                    |  6 +++---
 mk/eldo.el                        |  2 +-
 testing/examples/ob-awk-test.org  |  4 ++--
 testing/lisp/test-ob-sqlite.el    |  2 +-
 testing/lisp/test-org-agenda.el   |  2 +-
 testing/lisp/test-org-attach.el   |  2 +-
 testing/lisp/test-org.el          |  8 ++++----
 37 files changed, 83 insertions(+), 83 deletions(-)

diff --git a/README_maintainer b/README_maintainer
index a5eda1caf..d2e9ada50 100644
--- a/README_maintainer
+++ b/README_maintainer
@@ -42,7 +42,7 @@ The release number for minor releases look like this: =9.1.7=

 Minor releases are small amends to main releases.  Usually they fix
 critical bugs discovered in a main release.  Minor bugs are usually
-not fixed -- they will be adressed in the next main release.
+not fixed -- they will be addressed in the next main release.

 Only the fix to the bug is bundled into a release, without the main
 development work going on in the master branch.  Since the bug fix
@@ -194,7 +194,7 @@ The list of all contributors from who we have the papers is kept on
 Worg at https://orgmode.org/worg/org-contribute.html, so that
 committers can check if a patch can go into the core.

-The assignment process does not allways go smoothly, and it has
+The assignment process does not always go smoothly, and it has
 happened several times that it gets stuck or forgotten at the FSF.
 The contact at the FSF for this is: mailto:copyright-clerk@fsf.org

diff --git a/contrib/lisp/ob-oz.el b/contrib/lisp/ob-oz.el
index 626c4f316..46bf536f7 100644
--- a/contrib/lisp/ob-oz.el
+++ b/contrib/lisp/ob-oz.el
@@ -106,7 +106,7 @@ (require 'mozart nil t)
 ;; back any results from Oz to Emacs. The following code creates a
 ;; socket for sending code to the OPI compiler and results are
 ;; returned by the same socket. On the Oz side, a socket is opened and
-;; conected to the compiler of the OPI (via oz-send-string). On the
+;; connected to the compiler of the OPI (via oz-send-string). On the
 ;; Emacs side, a connection to this socket is created for feeding code
 ;; and receiving results. This additional communication channel to the
 ;; OPI compiler ensures that results are returned cleanly (e.g., only
diff --git a/contrib/lisp/ob-spice.el b/contrib/lisp/ob-spice.el
index 24ef3c874..c452c993f 100644
--- a/contrib/lisp/ob-spice.el
+++ b/contrib/lisp/ob-spice.el
@@ -58,7 +58,7 @@ (defun org-babel-expand-body:spice (body params)
           (progn  ;loop through the words
             (if (string-match "\\$\\(.*\\)\\[\\(.*\\)\\]" word)
                 (progn
-                  ;; if matchs a vector variable format
+                  ;; if matches a vector variable format
                   (setq varname (match-string 1 word))
                   (setq varindex (match-string 2 word))
                   ;; search varname in vars and use the value of varindex to word
@@ -75,7 +75,7 @@ (defun org-babel-expand-body:spice (body params)
               ) ; end of (if (string-match "\\$\\(.*\\)\\[\\(.*\\)\\]" word))
             (if (string-match "\\$\\(.*\\)\\." word) ; if variable has a dot in the end
                 (progn
-                  ;; if matchs a non-vector variable format
+                  ;; if matches a non-vector variable format
                   (setq varname (match-string 1 word))
                   (setq newword
                         (assoc-default varname vars
@@ -92,7 +92,7 @@ (defun org-babel-expand-body:spice (body params)
               );; end of (if (string-match "\\$\\(.*\\)\\." word)
             (if (string-match "\\$\\(.*\\)" word)
                 (progn
-                  ;; if matchs a non-vector variable format
+                  ;; if matches a non-vector variable format
                   (setq varname (match-string 1 word))
                   (setq newword
                         (assoc-default varname vars
diff --git a/contrib/lisp/ol-notmuch.el b/contrib/lisp/ol-notmuch.el
index 3ad82984c..d26d775a4 100644
--- a/contrib/lisp/ol-notmuch.el
+++ b/contrib/lisp/ol-notmuch.el
@@ -23,9 +23,9 @@

 ;;; Commentary:

-;; This file implements links to notmuch messages and "searchs". A
+;; This file implements links to notmuch messages and "searches". A
 ;; search is a query to be performed by notmuch; it is the equivalent
-;; to folders in other mail clients. Similarly, mails are refered to
+;; to folders in other mail clients. Similarly, mails are referred to
 ;; by a query, so both a link can refer to several mails.

 ;; Links have one the following form
@@ -35,7 +35,7 @@
 ;; The first form open the queries in notmuch-show mode, whereas the
 ;; second link open it in notmuch-search mode. Note that queries are
 ;; performed at the time the link is opened, and the result may be
-;; different from whet the link was stored.
+;; different from when the link was stored.

 ;;; Code:

diff --git a/contrib/lisp/org-annotate-file.el b/contrib/lisp/org-annotate-file.el
index b8e8bd9cb..e1f1f13cb 100644
--- a/contrib/lisp/org-annotate-file.el
+++ b/contrib/lisp/org-annotate-file.el
@@ -51,7 +51,7 @@
 ;; C-c C-l (on the above line for example) you will get:

 ;; * ~/org-annotate-file.el
-;; ** `org-annotate-file-add-search` to non-nil value.  Then whe...
+;; ** `org-annotate-file-add-search` to non-nil value.  Then when...

 ;; Note that both of the above will be links.

diff --git a/contrib/lisp/org-collector.el b/contrib/lisp/org-collector.el
index 833ecbf51..937d03eb4 100644
--- a/contrib/lisp/org-collector.el
+++ b/contrib/lisp/org-collector.el
@@ -111,7 +111,7 @@ (put 'org-collector-error

 (defun org-dblock-write:propview (params)
   "collect the column specification from the #+cols line
-preceeding the dblock, then update the contents of the dblock."
+preceding the dblock, then update the contents of the dblock."
   (interactive)
   (condition-case er
       (let ((cols (plist-get params :cols))
diff --git a/contrib/lisp/org-expiry.el b/contrib/lisp/org-expiry.el
index 5304d573f..a7ee0230d 100644
--- a/contrib/lisp/org-expiry.el
+++ b/contrib/lisp/org-expiry.el
@@ -52,7 +52,7 @@
 ;; This entry will expire on the 14th, january 2008, one week after its
 ;; creation date.
 ;;
-;; What happen when an entry is expired?  Nothing until you explicitely
+;; What happen when an entry is expired?  Nothing until you explicitly
 ;; M-x org-expiry-process-entries When doing this, org-expiry will check
 ;; for expired entries and request permission to process them.
 ;;
diff --git a/contrib/lisp/org-mac-link.el b/contrib/lisp/org-mac-link.el
index 6bd6dc5c9..7952b35fb 100644
--- a/contrib/lisp/org-mac-link.el
+++ b/contrib/lisp/org-mac-link.el
@@ -514,7 +514,7 @@ (defun as-get-selected-together-items ()
 ;;;###autoload
 (defun org-mac-together-get-selected ()
   (interactive)
-  (message "Applescript: Getting Togther items...")
+  (message "Applescript: Getting Together items...")
   (org-mac-paste-applescript-links (as-get-selected-together-items)))

 ;;;###autoload
diff --git a/contrib/lisp/org-passwords.el b/contrib/lisp/org-passwords.el
index 1f32f9b38..4bdd80491 100644
--- a/contrib/lisp/org-passwords.el
+++ b/contrib/lisp/org-passwords.el
@@ -348,7 +348,7 @@ (defun org-passwords-random-words-attach-number-of-words
        separator)))

 (defun org-passwords-substitute (string-to-change list-of-substitutions)
-  "Substitutes each appearence in STRING-TO-CHANGE of the `car' of
+  "Substitutes each appearance in STRING-TO-CHANGE of the `car' of
 each element of LIST-OF-SUBSTITUTIONS by the `cdr' of that
 element. For example:
  (org-passwords-substitute \"ab\" \'((\"a\" . \"b\") (\"b\" . \"c\")))
diff --git a/contrib/lisp/org-screenshot.el b/contrib/lisp/org-screenshot.el
index abac4a19c..58ebaa44b 100644
--- a/contrib/lisp/org-screenshot.el
+++ b/contrib/lisp/org-screenshot.el
@@ -86,7 +86,7 @@ (defgroup org-screenshot nil

 (defcustom org-screenshot-image-directory "./images/"
   "Directory in which screenshot image files will be stored, it
-be automatically created if it does't already exist."
+be automatically created if it doesn't already exist."
   :type 'string
   :group 'org-screenshot)

@@ -290,7 +290,7 @@ (defun org-screenshot-take (&optional delay)
                    (setq num (* num 4)
                          cnt (+ cnt (if (< cnt 3) 1 2))))
                  cnt))
-              (t (error "Invald delay"))))
+              (t (error "Invalid delay"))))
   (when (and org-screenshot-process
              (member (process-status org-screenshot-process)
                      '(run stop)))
@@ -331,7 +331,7 @@ (make-variable-buffer-local 'org-screenshot-file-list)
 (make-variable-buffer-local 'org-screenshot-rotation-index)

 (defun org-screenshot-rotation-init (lastfile)
-  "Initialize variable `org-screenshot-file-list' variabel with
+  "Initialize variable `org-screenshot-file-list' variable with
 the list of PNG files in `org-screenshot-image-directory' sorted
 by most recent first"
   (setq
diff --git a/contrib/lisp/org-sudoku.el b/contrib/lisp/org-sudoku.el
index 9537c0c0a..67665ffbe 100644
--- a/contrib/lisp/org-sudoku.el
+++ b/contrib/lisp/org-sudoku.el
@@ -1,4 +1,4 @@
-;;; org-sudoku.el --- Greate and solve SUDOKU games in Org tables
+;;; org-sudoku.el --- Create and solve SUDOKU games in Org tables

 ;; Copyright (C) 2012-2018 Free Software Foundation, Inc.
 ;;
diff --git a/contrib/lisp/org-toc.el b/contrib/lisp/org-toc.el
index 3a05c4a5d..08cc9e9bf 100644
--- a/contrib/lisp/org-toc.el
+++ b/contrib/lisp/org-toc.el
@@ -90,7 +90,7 @@ (defcustom org-toc-recenter 0

 (defcustom org-toc-info-exclude '("ALLTAGS")
   "A list of excluded properties when displaying info in the
-echo-area. The COLUMNS property is always exluded."
+echo-area. The COLUMNS property is always excluded."
   :group 'org-toc
   :type 'lits)

diff --git a/contrib/lisp/orgtbl-sqlinsert.el b/contrib/lisp/orgtbl-sqlinsert.el
index 759c464f2..49a455890 100644
--- a/contrib/lisp/orgtbl-sqlinsert.el
+++ b/contrib/lisp/orgtbl-sqlinsert.el
@@ -36,7 +36,7 @@ (defun orgtbl-to-sqlinsert (table params)
 Names and strings are modified slightly by default.  Single-ticks
 are doubled as per SQL's standard mechanism.  Backslashes and
 dollar signs are deleted.  And tildes are changed to spaces.
-These modifications were chosed for use with TeX.  See
+These modifications were chosen for use with TeX.  See
 ORGTBL-SQL-STRIP-AND-QUOTE.

 Supports all parameters from ORGTBL-TO-GENERIC.  New to this function
diff --git a/contrib/lisp/ox-groff.el b/contrib/lisp/ox-groff.el
index 85e24a5ec..97d307ad3 100644
--- a/contrib/lisp/ox-groff.el
+++ b/contrib/lisp/ox-groff.el
@@ -429,7 +429,7 @@ (defcustom org-groff-special-char
   is replace on the value of the CDR. "
   :group 'org-export-groff
   :type '(list
-          (cons :tag "Character Subtitute"
+          (cons :tag "Character Substitute"
                 (string :tag "Original Character Group")
                 (string :tag "Replacement Character"))))

diff --git a/contrib/lisp/ox-koma-letter.el b/contrib/lisp/ox-koma-letter.el
index abc0c2873..f3a27a3b1 100644
--- a/contrib/lisp/ox-koma-letter.el
+++ b/contrib/lisp/ox-koma-letter.el
@@ -921,7 +921,7 @@ (defun org-koma-letter-export-as-latex
 When optional argument BODY-ONLY is non-nil, only write code
 between \"\\begin{letter}\" and \"\\end{letter}\".

-EXT-PLIST, when provided, is a proeprty list with external
+EXT-PLIST, when provided, is a property list with external
 parameters overriding Org default settings, but still inferior to
 file-local settings.

diff --git a/contrib/lisp/ox-s5.el b/contrib/lisp/ox-s5.el
index 0496aae19..243332519 100644
--- a/contrib/lisp/ox-s5.el
+++ b/contrib/lisp/ox-s5.el
@@ -98,7 +98,7 @@ (defcustom org-s5-version "1.2a2"
   :type 'string)

 (defcustom org-s5-theme-file nil
-"Url to S5 theme (slides.css) file. Can be overriden with the
+"Url to S5 theme (slides.css) file. Can be overridden with the
 S5_THEME_FILE property. If nil, defaults to
 `org-s5-ui-url'/default/slides.css. If it starts with anything but
 \"http\" or \"/\", it is used as-is. Otherwise the link in generated
@@ -111,7 +111,7 @@ (defcustom org-s5-theme-file nil
 (defcustom org-s5-ui-url "ui"
   "Base url to directory containing S5 \"default\" subdirectory
 and the \"s5-notes.html\" file.
-Can be overriden with the S5_UI_URL property."
+Can be overridden with the S5_UI_URL property."
   :group 'org-export-s5
   :type 'string)

diff --git a/contrib/scripts/StartOzServer.oz b/contrib/scripts/StartOzServer.oz
index df3ebe636..79b86a8bc 100644
--- a/contrib/scripts/StartOzServer.oz
+++ b/contrib/scripts/StartOzServer.oz
@@ -74,10 +74,10 @@ MyCompiler = Emacs.condSend.compiler

 %% !! catching some exceptions does not work??

-%% exception is not catched
+%% exception is not caught
 try {Bla} catch E then {Error.printException E} {Browse nil} end

-%% exception is catched
+%% exception is caught
 try {Browse 1 div 0} catch E then {Error.printException E} {Browse nil} end
 {Browse ok}

diff --git a/doc/.aspell.org.conf b/doc/.aspell.org.conf
index facdc494b..dd8601d6f 100644
--- a/doc/.aspell.org.conf
+++ b/doc/.aspell.org.conf
@@ -68,7 +68,7 @@ suggest true
 # Miscellaneous
 #
 # Org documentation uses a lot of compound words.  Try and ignore them
-# rather than including them in a specfic word list.
+# rather than including them in a specific word list.

 run-together-limit 2
 run-together-min 2
diff --git a/doc/doc-setup.org b/doc/doc-setup.org
index 8f7ec4099..b0eef09bf 100644
--- a/doc/doc-setup.org
+++ b/doc/doc-setup.org
@@ -30,7 +30,7 @@
 # modifications.
 #+macro: version (eval (with-current-buffer (find-file-noselect "../lisp/org.el") (org-with-point-at 1 (if (re-search-forward "Version: +\\([0-9.]+\\)" nil t) (mapconcat #'identity (cl-subseq (split-string (match-string-no-properties 1) "\\.") 0 2) ".") (error "Missing \"Version\" keyword in \"org.el\"")))))

-# The "kbd" macro turns KBD into @kbd{KBD}.  Additionnally, it
+# The "kbd" macro turns KBD into @kbd{KBD}.  Additionally, it
 # encloses case-sensitive special keys (SPC, RET...) within @key{...}.
 #+macro: kbd (eval (let ((case-fold-search nil) (regexp (regexp-opt '("SPC" "RET" "LFD" "TAB" "BS" "ESC" "DELETE" "SHIFT" "Ctrl" "Meta" "Alt" "Cmd" "Super" "UP" "LEFT" "RIGHT" "DOWN") 'words))) (format "@@texinfo:@kbd{@@%s@@texinfo:}@@" (replace-regexp-in-string regexp "@@texinfo:@key{@@\\&@@texinfo:}@@" $1 t))))

diff --git a/doc/org-guide.org b/doc/org-guide.org
index db90702f7..9e76e5af0 100644
--- a/doc/org-guide.org
+++ b/doc/org-guide.org
@@ -806,7 +806,7 @@ a difference only in the agenda.
 #+attr_texinfo: :sep ;
 - {{{kbd(C-c \,)}}} ::

-  Set the priority of the current headline.  Pres {{{kbd(A)}}},
+  Set the priority of the current headline.  Press {{{kbd(A)}}},
   {{{kbd(B)}}} or {{{kbd(C)}}} to select a priority, or {{{kbd(SPC)}}}
   to remove the cookie.

diff --git a/doc/org-manual.org b/doc/org-manual.org
index 5e69ef074..286b9e004 100644
--- a/doc/org-manual.org
+++ b/doc/org-manual.org
@@ -1289,7 +1289,7 @@ Calculator Manual]]).
 Org makes it easy to format tables in plain ASCII.  Any line with =|=
 as the first non-whitespace character is considered part of a table.
 =|= is also the column separator[fn:17].  Moreover, a line starting
-with =|-= is a horizontal rule.  It separates rows explicitely.  Rows
+with =|-= is a horizontal rule.  It separates rows explicitly.  Rows
 before the first horizontal rule are header lines. A table might look
 like this:

@@ -3118,7 +3118,7 @@ Here is the full set of built-in link types:

 - =doi= ::

-  Link to an electronic ressource, through its handle.
+  Link to an electronic resource, through its handle.

 - =elisp= ::

@@ -8012,7 +8012,7 @@ mentioning.
   ~org-attach-id-to-path-function-list~ if you want the folder
   structure in any other way.  All functions in this list will be
   tried when resolving existing ID's into paths, to maintain backward
-  compatability with existing folders in your system.
+  compatibility with existing folders in your system.

 - ~org-attach-expert~ ::
   #+vindex: org-attach-expert
@@ -10879,7 +10879,7 @@ suited for source code and similar examples.
 There is one limitation, however.  You must insert a comma right
 before lines starting with either =*=, =,*=, =#+= or =,#+=, as those
 may be interpreted as outlines nodes or some other special syntax.
-Org transparently strips these additonal commas whenever it accesses
+Org transparently strips these additional commas whenever it accesses
 the contents of the block.

 #+begin_example
@@ -17402,7 +17402,7 @@ follows from the type specified above.
   Aligned if it is a table.  Usage example: =:results value raw=.

 #+cindex: @samp{wrap}, header argument
-The =wrap= header argument unconditionnally marks the results block by
+The =wrap= header argument unconditionally marks the results block by
 appending strings to =#+BEGIN_= and =#+END_=.  If no string is
 specified, Org wraps the results in a =#+BEGIN_results=
 ... =#+END_results= block.  It takes precedent over the =results=
diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index bdcfc24fd..283f32e0c 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -75,7 +75,7 @@ group 3.
 When tangling, user usually just wants to tangle literally code instead
 of prepend inserting a ~(ns ..)~ statement before source block
 code.  Now, when you have no ~:ns~ header argument specified, this
-behavior will not happend automatically.
+behavior will not happen automatically.
 *** Change in behavior on exit from an Org edit buffer
 Org will no longer attempt to restore the window configuration in the
 frame to which the user returns after editing a source block with
@@ -214,7 +214,7 @@ They are added mostly for internal restructuring purposes, but can
 ofc. be used for other things as well.

 *** New link-type: Attachment
-Attachment-links are now first-class citizens.  They mimick file-links
+Attachment-links are now first-class citizens.  They mimic file-links
 in everything they do but use the existing attachment-folder as a base
 when expanding the links. Both =DIR= and =ID= properties are used to
 try to resolve the links, in exactly the same way as Org-Attach uses
@@ -256,14 +256,14 @@ Supported LaTeX attributes are ~:float~, ~:center~, ~:font~ and
 *** Attach buffer contents to headline
 With =<b>= key from attachment dispatcher (=<C-c C-a>=), it is now
 possible to write the contents of a buffer to a file in the headline
-attachement directory.
+attachment directory.
 *** iCalendar export respects a =CLASS= property

 Set the =CLASS= property on an entry to specify a visibility class for
 that entry only during iCalendar export. The property can be set to
 anything the calendar server supports. The iCalendar standard defines
 the values =PUBLIC=, =CONFIDENTIAL=, =PRIVATE=, which can be
-interpreted as publicly visable, accessible to a specific group, and
+interpreted as publicly visible, accessible to a specific group, and
 private respectively.

 This property can be inherited during iCalendar export, depending on
@@ -296,8 +296,8 @@ days in the past.
 =<C-u K>= (~org-habit-toggle-display-in-agenda~) in an agenda toggles
 the display of all habits to those which are undone and scheduled.
 This is a function for convenience.
-*** New paramater for SQL Babel blocks: ~:dbconnection~
-The new paramater ~:dbconnection~ allows to specify a connection name
+*** New parameter for SQL Babel blocks: ~:dbconnection~
+The new parameter ~:dbconnection~ allows to specify a connection name
 in a SQL block header: this name is used to look up connection
 parameters in ~sql-connection-alist~.

@@ -358,10 +358,10 @@ You can install it back from MELPA.
 *** ~org-attach-directory~

 It has been deprecated in favour of ~org-attach-id-dir~ which is less
-ambigous given the restructured org-attach.
+ambiguous given the restructured org-attach.

 *** ~org-enable-fixed-width-editor~
-This variable was not used throught the code base.
+This variable was not used through the code base.
 ** Miscellaneous
 *** Change signature for ~org-list-to-subtree~
 The function now accepts the level of the subtree as an optional
@@ -456,7 +456,7 @@ Org 9.2 comes with a new template expansion mechanism, combining
 ~org-insert-structure-template~ bound to ~C-c C-,~.

 If you customized the ~org-structure-template-alist~ option manually,
-you probably need to udpate it, see the docstring for accepted values.
+you probably need to update it, see the docstring for accepted values.

 If you prefer using previous patterns, e.g. =<s=, you can activate
 them again by requiring Org Tempo library:
@@ -727,7 +727,7 @@ matcher.
 =ob-sql= library already support running SQL blocks against an Oracle
 database using ~sqlplus~.  Now it's possible to use alias names
 defined in =TNSNAMES= file instead of specifying full connection
-parameters.  See example bellow.
+parameters.  See example below.

 #+BEGIN_SRC org
   you can use the previous full connection parameters
@@ -781,7 +781,7 @@ will go back to the widen state.

 *** ~org-browse-news~

-Browse https://orgmode.org/Changes.html to let users read informations
+Browse https://orgmode.org/Changes.html to let users read information
 about the last major release.

 There is a new menu entry for this in the "Documentation" menu item.
@@ -2599,7 +2599,7 @@ everywhere in the buffer, possibly corrupting URLs.

 This undocumented option defaulted to the value of =shell-file-name= at
 the time of loading =ob-shell=.  The new behavior is to use the value
-of =shell-file-name= directly when the shell langage is =shell=.  To chose
+of =shell-file-name= directly when the shell language is =shell=.  To chose
 a different shell, either customize =shell-file-name= or bind this
 variable locally.

@@ -4677,7 +4677,7 @@ that Calc formulas can operate on them.

      : Percent escaping is used in Org mode to escape certain characters
      : in links that would either break the parser (e.g. square brackets
-     : in link target oder description) or are not allowed to appear in
+     : in link target or description) or are not allowed to appear in
      : a particular link type (e.g. non-ascii characters in a http:
      : link).
      :
diff --git a/lisp/ob-C.el b/lisp/ob-C.el
index 8cab96726..ca587ccbb 100644
--- a/lisp/ob-C.el
+++ b/lisp/ob-C.el
@@ -393,9 +393,9 @@ (defun org-babel-C-var-to-C (pair)
 	(setq val (string-to-char val))))
     (let* ((type-data (org-babel-C-val-to-C-type val))
 	   (type (car type-data))
-	   (formated (org-babel-C-format-val type-data val))
-	   (suffix (car formated))
-	   (data (cdr formated)))
+	   (formatted (org-babel-C-format-val type-data val))
+	   (suffix (car formatted))
+	   (data (cdr formatted)))
       (format "%s %s%s = %s;"
 	      type
 	      var
diff --git a/lisp/org-agenda.el b/lisp/org-agenda.el
index 4c3223c08..3f4e96393 100644
--- a/lisp/org-agenda.el
+++ b/lisp/org-agenda.el
@@ -3317,7 +3317,7 @@ (defmacro org-batch-agenda-csv (cmd-key &rest parameters)
 tags         All tags including inherited ones, separated by colons
 date         The relevant date, like 2007-2-14
 time         The time, like 15:00-16:50
-extra        Sting with extra planning info
+extra        String with extra planning info
 priority-l   The priority letter if any was given
 priority-n   The computed numerical priority
 agenda-day   The day in the agenda where this is listed"
@@ -7540,8 +7540,8 @@ (defun org-agenda-filter-by-top-headline (strip)
 (defvar org-agenda-regexp-filter nil)
 (defun org-agenda-filter-by-regexp (strip-or-accumulate)
   "Filter agenda entries by a regular expressions.
-You will be prompted for the regular expresssion, and the agenda
-view will only show entires that are matched by that expression.
+You will be prompted for the regular expression, and the agenda
+view will only show entries that are matched by that expression.

 With one `\\[universal-argument]' prefix argument, hide entries matching the regexp.
 When there is already a regexp filter active, this command removed the
@@ -10493,7 +10493,7 @@ (defun org-agenda-to-appt (&optional refresh filter &rest args)
                   (append entries
                           (apply 'org-agenda-get-day-entries
                                  file today scope)))))
-    ;; Map thru entries and find if we should filter them out
+    ;; Map through entries and find if we should filter them out
     (mapc
      (lambda (x)
        (let* ((evt (org-trim
diff --git a/lisp/org-attach-git.el b/lisp/org-attach-git.el
index cafead69e..525495f8c 100644
--- a/lisp/org-attach-git.el
+++ b/lisp/org-attach-git.el
@@ -1,4 +1,4 @@
-;;; org-attach-git.el --- Automatic git commit extention to org-attach -*- lexical-binding: t; -*-
+;;; org-attach-git.el --- Automatic git commit extension to org-attach -*- lexical-binding: t; -*-

 ;; Copyright (C) 2019 Free Software Foundation, Inc.

@@ -23,7 +23,7 @@

 ;;; Commentary:

-;; An extention to org-attach.  If `org-attach-id-dir' is initialized
+;; An extension to org-attach.  If `org-attach-id-dir' is initialized
 ;; as a Git repository, then org-attach-git will automatically commit
 ;; changes when it sees them.  Requires git-annex.

diff --git a/lisp/org-feed.el b/lisp/org-feed.el
index 826e761d7..f9f5fb051 100644
--- a/lisp/org-feed.el
+++ b/lisp/org-feed.el
@@ -407,7 +407,7 @@ (defun org-feed-update (feed &optional retrieve-only)
 	  ;; Write the new status
 	  ;; We do this only now, in case something goes wrong above, so
 	  ;; that would would end up with a status that does not reflect
-	  ;; which items truely have been handled
+	  ;; which items truly have been handled
 	  (org-feed-write-status inbox-pos drawer status)

 	  ;; Normalize the visibility of the inbox tree
diff --git a/lisp/org-plot.el b/lisp/org-plot.el
index a5635e326..4e84dbe09 100644
--- a/lisp/org-plot.el
+++ b/lisp/org-plot.el
@@ -131,7 +131,7 @@ (defun org-plot/gnuplot-to-grid-data (table data-file params)
   "Export the data in TABLE to DATA-FILE for gnuplot.
 This means in a format appropriate for grid plotting by gnuplot.
 PARAMS specifies which columns of TABLE should be plotted as independent
-and dependant variables."
+and dependent variables."
   (interactive)
   (let* ((ind (- (plist-get params :ind) 1))
 	 (deps (if (plist-member params :deps)
diff --git a/lisp/org-table.el b/lisp/org-table.el
index df43dd634..a21587acb 100644
--- a/lisp/org-table.el
+++ b/lisp/org-table.el
@@ -4265,7 +4265,7 @@ (defun org-table-export (&optional file format)

 ;;;###autoload
 (defun org-table--align-field (field width align)
-  "Format FIELD according to column WIDTH and alignement ALIGN.
+  "Format FIELD according to column WIDTH and alignment ALIGN.
 FIELD is a string.  WIDTH is a number.  ALIGN is either \"c\",
 \"l\" or\"r\"."
   (let* ((spaces (- width (org-string-width field)))
diff --git a/lisp/org.el b/lisp/org.el
index f29298266..dcca043e0 100644
--- a/lisp/org.el
+++ b/lisp/org.el
@@ -3139,7 +3139,7 @@ (defcustom org-columns-default-format "%25ITEM %TODO %3PRIORITY %TAGS"

 (defcustom org-columns-default-format-for-agenda nil
   "The default column format in an agenda buffer.
-Whis will be used for column view in the agenda unless a format has
+This will be used for column view in the agenda unless a format has
 been set by adding `org-overriding-columns-format' to the local
 settings list of a custom agenda view.  When nil, the columns format
 for the first item in the agenda list will be used, or as a fall-back,
@@ -11572,7 +11572,7 @@ (defun org-priority (&optional action show)
 When called interactively with a `\\[universal-argument]' prefix,
 show the priority in the minibuffer instead of changing it.

-When called programatically, ACTION can be `set', `up', `down',
+When called programmatically, ACTION can be `set', `up', `down',
 or a character."
   (interactive "P")
   (when show
@@ -16340,7 +16340,7 @@ (defun org-format-latex
 (defun org-create-math-formula (latex-frag &optional mathml-file)
   "Convert LATEX-FRAG to MathML and store it in MATHML-FILE.
 Use `org-latex-to-mathml-convert-command'.  If the conversion is
-sucessful, return the portion between \"<math...> </math>\"
+successful, return the portion between \"<math...> </math>\"
 elements otherwise return nil.  When MATHML-FILE is specified,
 write the results in to that file.  When invoked as an
 interactive command, prompt for LATEX-FRAG, with initial value
diff --git a/lisp/ox-odt.el b/lisp/ox-odt.el
index be591928e..f9c4a93cc 100644
--- a/lisp/ox-odt.el
+++ b/lisp/ox-odt.el
@@ -814,7 +814,7 @@ (defcustom org-odt-table-styles
 TABLE-STYLE-NAME is the style associated with the table through
 \"#+ATTR_ODT: :style TABLE-STYLE-NAME\" line.

-TABLE-TEMPLATE-NAME is a set of - upto 9 - automatic
+TABLE-TEMPLATE-NAME is a set of - up to 9 - automatic
 TABLE-CELL-STYLE-NAMEs and PARAGRAPH-STYLE-NAMEs (as defined
 below) that is included in `org-odt-content-template-file'.

@@ -1414,7 +1414,7 @@ (defun org-odt-template (contents info)
       ;; the resulting odt file.
       (setq-local backup-inhibited t)

-      ;; Outline numbering is retained only upto LEVEL.
+      ;; Outline numbering is retained only up to LEVEL.
       ;; To disable outline numbering pass a LEVEL of 0.

       (goto-char (point-min))
@@ -3241,7 +3241,7 @@ (defun org-odt-get-table-cell-styles (table-cell info)
     (when style-spec
       ;; LibreOffice - particularly the Writer - honors neither table
       ;; templates nor custom table-cell styles.  Inorder to retain
-      ;; inter-operability with LibreOffice, only automatic styles are
+      ;; interoperability with LibreOffice, only automatic styles are
       ;; used for styling of table-cells.  The current implementation is
       ;; congruent with ODF-1.2 specification and hence is
       ;; future-compatible.
diff --git a/mk/eldo.el b/mk/eldo.el
index 6a5675aed..ba8c46400 100644
--- a/mk/eldo.el
+++ b/mk/eldo.el
@@ -100,7 +100,7 @@ (defun eldo-write-hooks (hooks)
     (goto-char (point-max))))

 (defun eldo-write-commands (commands)
-  "Write commands documentaiton in the current buffer."
+  "Write commands documentation in the current buffer."
   (insert "\n* Commands\n")
   (org-set-property "CUSTOM_ID" "commands")
   (dolist (c commands)
diff --git a/testing/examples/ob-awk-test.org b/testing/examples/ob-awk-test.org
index 63e070ff8..f9b73125a 100644
--- a/testing/examples/ob-awk-test.org
+++ b/testing/examples/ob-awk-test.org
@@ -6,13 +6,13 @@
   :ID:       9e998b2a-3581-43fe-b26d-07d3c507b86a
   :END:
 Run without input stream
-#+begin_src awk :ouput silent :results silent
+#+begin_src awk :output silent :results silent
   BEGIN {
       print 42
   }
 #+end_src

-Use a code block ouput as an input
+Use a code block output as an input
 #+begin_src awk  :stdin genseq :results silent
   {
       print 42+$1
diff --git a/testing/lisp/test-ob-sqlite.el b/testing/lisp/test-ob-sqlite.el
index 4a66a0813..f6ffa6ab4 100644
--- a/testing/lisp/test-ob-sqlite.el
+++ b/testing/lisp/test-ob-sqlite.el
@@ -25,7 +25,7 @@ (unless (featurep 'ob-sqlite)
   (signal 'missing-test-dependency "Support for sqlite code blocks"))

 (ert-deftest ob-sqlite/table-variables-with-commas ()
-  "Test of a table variable that contains commas. This garantees that this code path results in a valid CSV."
+  "Test of a table variable that contains commas. This guarantees that this code path results in a valid CSV."
   (should
    (equal '(("Mr Test A. Sql"
 	     "Minister for Science, Eternal Happiness, and Finance"))
diff --git a/testing/lisp/test-org-agenda.el b/testing/lisp/test-org-agenda.el
index bdee2bfe7..17822272f 100644
--- a/testing/lisp/test-org-agenda.el
+++ b/testing/lisp/test-org-agenda.el
@@ -28,7 +28,7 @@ (require 'org-agenda)
 (eval-and-compile (require 'cl-lib))

 \f
-;; General auxilliaries
+;; General auxiliaries

 (defun org-test-agenda--agenda-buffers ()
   "Return agenda buffers in a list."
diff --git a/testing/lisp/test-org-attach.el b/testing/lisp/test-org-attach.el
index 37cc39d85..f910526c2 100644
--- a/testing/lisp/test-org-attach.el
+++ b/testing/lisp/test-org-attach.el
@@ -98,7 +98,7 @@ (ert-deftest test-org-attach/dir ()
 		 (org-test-in-example-file org-test-attachments-file
 		   (goto-char 401) ;; H3.1
 		   (let ((org-attach-use-inheritance t))
-		     ;; This is where it get's a bit sketchy...! DIR always has
+		     ;; This is where it gets a bit sketchy...! DIR always has
 		     ;; priority over ID, even if ID is declared "higher up" in the
 		     ;; tree.  This can potentially be revised.  But it is also
 		     ;; pretty clean.  DIR is always higher in priority than ID right
diff --git a/testing/lisp/test-org.el b/testing/lisp/test-org.el
index 215d8fdb0..29c6ed754 100644
--- a/testing/lisp/test-org.el
+++ b/testing/lisp/test-org.el
@@ -2516,7 +2516,7 @@ (ert-deftest test-org/open-at-point/tag ()
 		  (lambda (&rest args) (throw :result t))))
 	 ;; When point isn't on a tag it's going to try other things,
 	 ;; possibly trying to open attachments which will return an
-	 ;; error if there isn't an attachment. Supress that error.
+	 ;; error if there isn't an attachment. Suppress that error.
 	 (ignore-errors
 	     (org-open-at-point))
 	 nil)))))
@@ -4862,7 +4862,7 @@ (ert-deftest test-org/schedule ()

 (ert-deftest test-org/buffer-property-keys ()
   "Test `org-buffer-property-keys' specifications."
-  ;; Retrieve properties accross siblings.
+  ;; Retrieve properties across siblings.
   (should
    (equal '("A" "B")
 	  (org-test-with-temp-text "
@@ -4875,7 +4875,7 @@ (ert-deftest test-org/buffer-property-keys ()
 :B: 1
 :END:"
 	    (org-buffer-property-keys))))
-  ;; Retrieve properties accross children.
+  ;; Retrieve properties across children.
   (should
    (equal '("A" "B")
 	  (org-test-with-temp-text "
@@ -6258,7 +6258,7 @@ (ert-deftest test-org/toggle-tag ()

 (ert-deftest test-org/tags-expand ()
   "Test `org-tags-expand' specifications."
-  ;; Expand tag groups as a regexp enclosed withing curly brackets.
+  ;; Expand tag groups as a regexp enclosed within curly brackets.
   (should
    (equal "{\\<[ABC]\\>}"
 	  (org-test-with-temp-text "#+TAGS: [ A : B C ]"
diff --git a/contrib/lisp/ox-deck.el b/contrib/lisp/ox-deck.el
index 427c7d765..3b911e16e 100644
--- a/contrib/lisp/ox-deck.el
+++ b/contrib/lisp/ox-deck.el
@@ -32,7 +32,7 @@
 ;;
 ;; Add the path to the extracted code to the variable
 ;; `org-deck-directories' There are a number of customization in the
 ;; org-export-deck group, most of which can be overrriden with buffer
 ;; local customization (starting with DECK_.)

 ;; See ox.el and ox-html.el for more details on how this exporter
@@ -137,7 +137,7 @@ (defun org-deck-list-components ()

 (defcustom org-deck-include-extensions nil
   "If non-nil, list of extensions to include instead of all available.
-Can be overriden or set with the DECK_INCLUDE_EXTENSIONS property.
+Can be overridden or set with the DECK_INCLUDE_EXTENSIONS property.
 During output generation, the extensions found by
 `org-deck--find-extensions' are searched for the appropriate
 files (scripts and/or stylesheets) to include in the generated
@@ -147,12 +147,12 @@ (defcustom org-deck-include-extensions nil

 (defcustom org-deck-exclude-extensions nil
   "If non-nil, list of extensions to exclude.
-Can be overriden or set with the DECK_EXCLUDE_EXTENSIONS property."
+Can be overridden or set with the DECK_EXCLUDE_EXTENSIONS property."
   :group 'org-export-deck
   :type '(repeat (string :tag "Extension")))

 (defcustom org-deck-theme "swiss.css"
-  "deck.js theme. Can be overriden with the DECK_THEME property.
+  "deck.js theme. Can be overridden with the DECK_THEME property.
 If this value contains a path component (\"/\"), it is used as a
 literal path (url). Otherwise it is prepended with
 `org-deck-base-url'/themes/style/."
@@ -160,7 +160,7 @@ (defcustom org-deck-theme "swiss.css"
   :type 'string)

 (defcustom org-deck-transition "fade.css"
-  "deck.js transition theme. Can be overriden with the
+  "deck.js transition theme. Can be overridden with the
 DECK_TRANSITION property.
 If this value contains a path component (\"/\"), it is used as a
 literal path (url). Otherwise it is prepended with
@@ -171,7 +171,7 @@ (defcustom org-deck-transition "fade.css"
 (defcustom org-deck-base-url "deck.js"
   "Url prefix to deck.js base directory containing the core, extensions
 and themes directories.
-Can be overriden with the DECK_BASE_URL property."
+Can be overridden with the DECK_BASE_URL property."
   :group 'org-export-deck
   :type 'string)

@@ -180,7 +180,7 @@ (defvar org-deck-pre/postamble-styles
     (preamble "position: absolute; top: 10px;")
     (postamble ""))
   "Alist of css styles for the preamble, postamble and both respectively.
-Can be overriden in `org-deck-styles'. See also `org-html-divs'.")
+Can be overridden in `org-deck-styles'. See also `org-html-divs'.")

 (defcustom org-deck-postamble "<h1>%a - %t</h1>"
   "Non-nil means insert a postamble in HTML export.
@@ -239,7 +239,7 @@ (defvar org-deck-toc-styles
     "#table-of-contents ul {margin-bottom: 0;}"
     "#table-of-contents li {padding: 0;}") "\n")
   "Default css styles used for formatting a table of contents slide.
-Can be overriden in `org-deck-styles'.
+Can be overridden in `org-deck-styles'.
 Note that when the headline numbering option is true, a \"list-style: none\"
 is automatically added to avoid both numbers and bullets on the toc entries.")
@@ -32,7 +32,7 @@
 ;; Add the path to the extracted code to the variable
 ;; `org-deck-directories' There are a number of customization in the
-;; org-export-deck group, most of which can be overrriden with buffer
+;; org-export-deck group, most of which can be overridden with buffer
 ;; local customization (starting with DECK_.)


--
2.24.0

             reply	other threads:[~2019-11-12 13:47 UTC|newest]

Thread overview: 14+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2019-11-12 13:44 Jonas Bernoulli [this message]
2019-11-16 22:36 ` [PATCH] Fix typos Kyle Meyer
2019-11-16 23:07   ` Kyle Meyer
  -- strict thread matches above, loose matches on Subject: below --
2022-06-30 15:34 Stefan Kangas
2022-07-01  9:45 ` Ihor Radchenko
2012-03-05  0:01 Adam Spiers
2012-03-08 12:51 ` Bastien
2009-05-10  2:34 Nick Dokos
2009-05-10  7:17 ` Carsten Dominik
2009-05-10 13:46 ` Richard Riley
2009-05-10 16:22   ` Nick Dokos
2009-05-10 16:29     ` Nick Dokos
2009-05-10 16:38     ` Richard Riley
2009-05-10 17:22     ` Richard Riley

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://www.orgmode.org/

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=874kz9mcpm.fsf@bernoul.li \
    --to=jonas@bernoul.li \
    --cc=emacs-orgmode@gnu.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).